@@ -18,6 +18,13 @@ elif 'CFG_INVENIO_SRC' in os.environ:
 else:
     SRC_PATH = [os.path.expanduser("~/src/invenio"), ]
 
+# Check if CFG_INVENIO_SRC is set otherwise use default.
+if 'CFG_INSPIRE_SRCDIR' in os.environ:
+    SRC_PATH += [os.environ['CFG_INSPIRE_SRCDIR']]
+elif 'CFG_INSPIRE_SRC' in os.environ:
+    SRC_PATH += [os.environ['CFG_INSPIRE_SRC']]
+else:
+    SRC_PATH += [os.path.expanduser("~/src/inspire"), ]
 
 # Try if we're in a virtualenv or CFG_INVENIO_PREFIX is set.
 INSTALL_PATH = "/opt/invenio/"
