@@ -35,8 +35,6 @@ except NameError:
 
 DESCRIPTION = "Invenio web server for development"
 USAGE_MESSAGE = "python serve.py [-bp]"
-RE_BIBFORMAT_ELEMENTS = re.compile(ur"^(/modules/bibformat/lib/elements/.+\.py|/bibformat/format_elements/.+\.py)",
-                                   re.U|re.I)
 
 
 def get_extension(filename):
@@ -77,18 +75,23 @@ def select_destination_path(filename, install_path=config.INSTALL_PATH,
     rel_path = filename
     for src_path in config.SRC_PATH:
         if rel_path.startswith(src_path):
-            rel_path = rel_path.replace(src_path, '')
+            rel_path = rel_path.replace('%s/' % src_path, '')
             break
 
     ext = get_extension(filename)
     lib_dir = dests[ext]
+
+    for regexp, dest_dir in config.SPECIAL_DIRS_RE.iteritems():
+        m = regexp.match(rel_path)
+        if m:
+            lib_dir = dest_dir % m.groupdict()
+            break
+
     if lib_dir:
-        if ext == 'py':
-            if RE_BIBFORMAT_ELEMENTS.match(rel_path):
-                lib_dir = os.path.join(lib_dir, 'bibformat_elements')
         dest = os.path.join(install_path,
                             lib_dir,
                             os.path.basename(filename))
+
     return dest
 
 
@@ -123,7 +126,7 @@ def reloader_loop(files, reloader=None, interval=1):
             if old_time is None:
                 mtimes[filename] = mtime
                 dest = select_destination_path(filename)
-                if os.path.isfile(dest):
+                if dest and os.path.isfile(dest):
                     old_time = os.stat(dest).st_mtime
                 else:
                     old_time = mtime
