@@ -1,4 +1,6 @@
 import traceback
+import warnings
+from functools import wraps
 
 
 def replace_error_handler():
@@ -16,15 +18,17 @@ def replace_error_handler():
 
 
 def wrap_warn():
-    import warnings
 
-    def wrapper(warn_fun):
-        def fun(*args, **kwargs):
-            traceback.print_stack()
-            return warn_fun(*args, **kwargs)
-        return fun
+    @wraps(warnings.showwarning)
+    def cb_showwarning(message=None, category=None, filename=None, lineno=None, file=None, line=None):
+        print "WARNING: %(category)s: %(message)s (%(file)s:%(line)s)\n" % {
+            'category': category,
+            'message': message,
+            'file': filename,
+            'line': lineno}
+        traceback.print_stack()
 
-    warnings.warn = wrapper(warnings.warn)
+    warnings.showwarning = cb_showwarning
 
 
 try:
